import { Adapter, LoggingTypes, FormatConfig, Colors } from "./types";
export declare function removeColors(text: string): string;
export interface LoggingBaseOptions {
    /**
     * Name will be prefixed on Console output and added to logfiles, if not specified here
     */
    name: string;
    /**
     * Prints output to console
     */
    console: boolean;
}
export declare class LoggingBase {
    private _formatMap;
    set formatMap(value: FormatConfig);
    private adapter;
    private adapter_init;
    private timerMap;
    private messageObservable;
    protected _name: string;
    private _logLevel;
    get logLevel(): LoggingTypes;
    set logLevel(value: LoggingTypes);
    get name(): string;
    constructor(options?: Partial<LoggingBaseOptions> | string);
    addAdapter(adapter: Adapter): void;
    flush(sync: true): void;
    flush(sync: false): Promise<void>;
    close(): void;
    waitForSetup(): Promise<void[]>;
    debug(...message: any[]): void;
    log(...message: any[]): void;
    warning(...message: any[]): void;
    warn(...message: any[]): void;
    error(error: Error | string): void;
    errorMessage(...message: any[]): void;
    protected getCurrentTime(): number;
    /**
     * The time difference in milliseconds (fractions allowed!)
     * @param start Start time from getCurrentTime
     */
    protected getTimeDiff(start: any): number;
    time(id?: string, name?: string): {
        id: string;
        end: () => void;
    };
    timeEnd(id: string): void;
    private message;
}
declare const colorSymbol: unique symbol;
export interface ColorFormat {
    [colorSymbol]: Colors;
    value: any;
}
export declare function withColor(color: Colors, value: any): ColorFormat;
export {};
